/*
 * Copyright (C) 2009 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.example.hellojni;

import java.util.Date;

import android.app.Activity;
import android.content.Context;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Paint;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.FrameLayout;
import android.widget.TextView;
import android.os.Bundle;


public class ChartActivity extends Activity
{
    /** Called when the activity is first created. */
    @Override
    public void onCreate(Bundle savedInstanceState)
    {
        super.onCreate(savedInstanceState);

        FrameLayout frameLayout = new FrameLayout(getApplicationContext());
        setContentView(frameLayout);
        String text = HelloJni.doStringFromJNI("0");
        String[] dataStr=text.split("\n");
        long[] data =new long[dataStr.length];
        for (int i=0;i<dataStr.length;i++)
        	data[i]=Long.valueOf(dataStr[i]);

        MyView myView = new MyView(getApplicationContext());
        myView.setData(data);
        frameLayout.addView(myView);
		
        // for...
        
    }
    
    class MyView extends View {

		public MyView(Context context) {
			super(context);
		}
		
		long[] data = null;
		public void setData(long[] data) {
			this.data = data;
			this.invalidate();
		}
		@Override
		protected void onDraw(Canvas canvas) {
			super.onDraw(canvas);
			
			Paint paint = new Paint();
			paint.setColor(Color.WHITE);
			for (int i=0;i<data.length;i++)
				canvas.drawPoint(i+4, 250-data[i], paint);
			canvas.drawLine(0, 250, data.length+4, 250, paint);
			canvas.drawText("n=0", 0, 255, paint);
			canvas.drawText("n=250", 254, 255, paint);
			canvas.drawText("n=500", 554, 255, paint);
		}
		
		
    }
    /* A native method that is implemented by the
     * 'hello-jni' native library, which is packaged
     * with this application.
     */
    public native String  stringFromJNI(String nStr);

    /* This is another native method declaration that is *not*
     * implemented by 'hello-jni'. This is simply to show that
     * you can declare as many native methods in your Java code
     * as you want, their implementation is searched in the
     * currently loaded native libraries only the first time
     * you call them.
     *
     * Trying to call this function will result in a
     * java.lang.UnsatisfiedLinkError exception !
     */
    public native String  unimplementedStringFromJNI();

    /* this is used to load the 'hello-jni' library on application
     * startup. The library has already been unpacked into
     * /data/data/com.example.HelloJni/lib/libhello-jni.so at
     * installation time by the package manager.
     */
    static {
        System.loadLibrary("hello-jni");
    }
}
